==> apache-geode-1.4.0-src.zip: apache-geode-1.4.0-src/geode-core/src/main/java/org/apache/geode/internal/cache/partitioned/OfflineMemberDetails.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.partitioned;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.Collections;
import java.util.Set;

import org.apache.geode.DataSerializable;
import org.apache.geode.internal.cache.persistence.PersistentMemberID;

/**
 *
 */
public interface OfflineMemberDetails extends DataSerializable {

  public static final OfflineMemberDetails EMPTY_DETAILS = new OfflineMemberDetails() {
    public Set<PersistentMemberID> getOfflineMembers(int bucketId) {
      return Collections.emptySet();
    }

    public void fromData(DataInput in) throws IOException, ClassNotFoundException {}

    public void toData(DataOutput out) throws IOException {}
  };

  public Set<PersistentMemberID> getOfflineMembers(int bucketId);
}

==> apache-geode-1.7.0-src.zip: apache-geode-1.7.0-src/geode-core/src/main/java/org/apache/geode/internal/cache/partitioned/OfflineMemberDetails.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache.partitioned;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.Collections;
import java.util.Set;

import org.apache.geode.DataSerializable;
import org.apache.geode.internal.cache.persistence.PersistentMemberID;

public interface OfflineMemberDetails extends DataSerializable {

  OfflineMemberDetails EMPTY_DETAILS = new OfflineMemberDetails() {
    public Set<PersistentMemberID> getOfflineMembers(int bucketId) {
      return Collections.emptySet();
    }

    public void fromData(DataInput in) throws IOException, ClassNotFoundException {}

    public void toData(DataOutput out) throws IOException {}
  };

  Set<PersistentMemberID> getOfflineMembers(int bucketId);
}
